@@ -326,10 +326,13 @@ class Client(ApplicationSession):
             }
             member_data['level'] = MEMBER_LEVEL_TO_STR.get(member_level, None)
 
-            self.log.info('Member found:\n\n{member_data}\n', member_data=pformat(member_data))
+            self.log.info('Member {member_oid} found for address 0x{member_adr} - current member level {member_level}',
+                          member_level=hlval(member_data['level']),
+                          member_oid=hlid(member_data['oid']),
+                          member_adr=hlval(member_data['address']))
         else:
             self.log.warn('Address 0x{member_adr} is not a member in the XBR network',
-                          member_adr=binascii.b2a_hex(member_adr).decode())
+                          member_adr=hlval(binascii.b2a_hex(member_adr).decode()))
 
     async def _do_get_actor(self, market_oid, actor_adr):
         is_member = await self.call('xbr.network.is_member', actor_adr)
@@ -460,8 +463,9 @@ class Client(ApplicationSession):
         assert 'created' in result and type(result['created']) == int and result['created'] > 0
 
         member_oid = result['member_oid']
-        self.log.info('SUCCESS! New XBR Member onboarded: member_oid={member_oid}, result=\n{result}',
-                      member_oid=uuid.UUID(bytes=member_oid), result=pformat(result))
+        self.log.info('SUCCESS! New XBR Member onboarded: member_oid={member_oid}, transaction={transaction}',
+                      member_oid=hlid(uuid.UUID(bytes=member_oid)),
+                      transaction=hlval('0x' + binascii.b2a_hex(result['transaction']).decode()))
 
     async def _do_create_market(self, member_oid, market_oid, marketmaker, title=None, label=None, homepage=None,
                                 provider_security=0, consumer_security=0, market_fee=0):
@@ -780,6 +784,20 @@ class Client(ApplicationSession):
         return txn_hash
 
 
+def print_version():
+    print('')
+    print(' XBR CLI {}\n'.format(hlval('v' + __version__)))
+    print('')
+    print('   Contract addresses:\n')
+    print('      XBRToken   : {} [source: {}]'.format(hlid(XBR_DEBUG_TOKEN_ADDR), XBR_DEBUG_TOKEN_ADDR_SRC))
+    print('      XBRNetwork : {} [source: {}]'.format(hlid(XBR_DEBUG_NETWORK_ADDR), XBR_DEBUG_NETWORK_ADDR_SRC))
+    print('      XBRDomain  : {} [source: {}]'.format(hlid(XBR_DEBUG_DOMAIN_ADDR), XBR_DEBUG_DOMAIN_ADDR_SRC))
+    print('      XBRCatalog : {} [source: {}]'.format(hlid(XBR_DEBUG_CATALOG_ADDR), XBR_DEBUG_CATALOG_ADDR_SRC))
+    print('      XBRMarket  : {} [source: {}]'.format(hlid(XBR_DEBUG_MARKET_ADDR), XBR_DEBUG_MARKET_ADDR_SRC))
+    print('      XBRChannel : {} [source: {}]'.format(hlid(XBR_DEBUG_CHANNEL_ADDR), XBR_DEBUG_CHANNEL_ADDR_SRC))
+    print('')
+
+
 def _main():
     parser = argparse.ArgumentParser()
 
@@ -941,21 +959,8 @@ def _main():
 
     args = parser.parse_args()
 
-    # read or create a user profile
-    profile = load_or_create_profile()
-
     if args.command == 'version':
-        print('')
-        print(' XBR CLI {}\n'.format(hlval('v' + __version__)))
-        print('   Profile {profile} loaded from {path}\n'.format(profile=hlval(profile.name), path=hlval(profile.path)))
-        print('   Contract addresses:\n')
-        print('      XBRToken   : {} [source: {}]'.format(hlid(XBR_DEBUG_TOKEN_ADDR), XBR_DEBUG_TOKEN_ADDR_SRC))
-        print('      XBRNetwork : {} [source: {}]'.format(hlid(XBR_DEBUG_NETWORK_ADDR), XBR_DEBUG_NETWORK_ADDR_SRC))
-        print('      XBRDomain  : {} [source: {}]'.format(hlid(XBR_DEBUG_DOMAIN_ADDR), XBR_DEBUG_DOMAIN_ADDR_SRC))
-        print('      XBRCatalog : {} [source: {}]'.format(hlid(XBR_DEBUG_CATALOG_ADDR), XBR_DEBUG_CATALOG_ADDR_SRC))
-        print('      XBRMarket  : {} [source: {}]'.format(hlid(XBR_DEBUG_MARKET_ADDR), XBR_DEBUG_MARKET_ADDR_SRC))
-        print('      XBRChannel : {} [source: {}]'.format(hlid(XBR_DEBUG_CHANNEL_ADDR), XBR_DEBUG_CHANNEL_ADDR_SRC))
-        print('')
+        print_version()
 
     elif args.command == 'describe-schema':
         schema = FbsSchema.load(args.schema)
@@ -1035,15 +1040,15 @@ def _main():
                 if is_first_by_category:
                     is_first_by_category_modules[(modulename, category)] = True
 
-                # render object type template into python code section
+                # render template into python code section
                 if args.language == 'python':
                     # render obj|enum|service.py.jinja2 template
                     tmpl = env.get_template('{}.py.jinja2'.format(category))
-                    code = tmpl.render(metadata=metadata, FbsType=FbsType, render_imports=is_first, is_first_by_category=is_first_by_category)
+                    code = tmpl.render(repo=repo, metadata=metadata, FbsType=FbsType, render_imports=is_first, is_first_by_category=is_first_by_category)
 
                     # render test_obj|enum|service.py.jinja2 template
                     test_tmpl = env.get_template('test_{}.py.jinja2'.format(category))
-                    test_code = test_tmpl.render(metadata=metadata, FbsType=FbsType, render_imports=is_first, is_first_by_category=is_first_by_category)
+                    test_code = test_tmpl.render(repo=repo, metadata=metadata, FbsType=FbsType, render_imports=is_first, is_first_by_category=is_first_by_category)
                 elif args.language == 'json':
                     code = json.dumps(metadata.marshal(),
                                       separators=(', ', ': '),
@@ -1067,6 +1072,7 @@ def _main():
         # write out code modules
         #
         i = 0
+        initialized = set()
         for code_file, code_sections in code_modules.items():
             code = '\n\n\n'.join(code_sections)
             if code_file:
@@ -1084,8 +1090,9 @@ def _main():
                             _modulename = '.'.join(code_file_dir[:i + 1])[1:]
                             with open(fn, 'wb') as f:
                                 tmpl = env.get_template('module.py.jinja2')
-                                init_code = tmpl.render(modulename=_modulename)
+                                init_code = tmpl.render(repo=repo, modulename=_modulename)
                                 f.write(init_code.encode('utf8'))
+                            initialized.add(fn)
 
             if args.language == 'python':
                 if code_file:
@@ -1100,15 +1107,28 @@ def _main():
                 else:
                     code_file_name = 'init.json'
                 test_code_file_name = None
+            else:
+                code_file_name = None
+                test_code_file_name = None
 
-            fn = os.path.join(*(code_file_dir + [code_file_name]))
-            fn = os.path.join(args.output, fn)
+            # write out code modules
+            #
+            if code_file_name:
+                data = code.encode('utf8')
 
-            data = code.encode('utf8')
-            with open(fn, 'ab') as fd:
-                fd.write(data)
+                fn = os.path.join(*(code_file_dir + [code_file_name]))
+                fn = os.path.join(args.output, fn)
 
-            print('Ok, written {} bytes to {}'.format(len(data), fn))
+                if fn not in initialized and os.path.exists(fn):
+                    os.remove(fn)
+                    with open(fn, 'wb') as fd:
+                        fd.write('# Generated by Autobahn v{}\n'.format(__version__).encode('utf8'))
+                    initialized.add(fn)
+
+                with open(fn, 'ab') as fd:
+                    fd.write(data)
+
+                print('Ok, written {} bytes to {}'.format(len(data), fn))
 
             # write out unit test code modules
             #
@@ -1120,16 +1140,25 @@ def _main():
                 fn = os.path.join(*(code_file_dir + [test_code_file_name]))
                 fn = os.path.join(args.output, fn)
 
+                if fn not in initialized and os.path.exists(fn):
+                    os.remove(fn)
+                    with open(fn, 'wb') as fd:
+                        fd.write('# Copyright (c) ...'.encode('utf8'))
+                    initialized.add(fn)
+
                 with open(fn, 'ab') as fd:
                     fd.write(data)
 
                 print('Ok, written {} bytes to {}'.format(len(data), fn))
-
     else:
         if args.command is None or args.command == 'noop':
             print('no command given. select from: {}'.format(', '.join(_COMMANDS)))
             sys.exit(0)
 
+        # read or create a user profile
+        profile = load_or_create_profile(default_url=args.url, default_realm=args.realm,
+                                         default_username=args.username, default_email=args.email)
+
         # only start txaio logging after above, which runs click (interactively)
         if args.debug:
             txaio.start_logging(level='debug')
@@ -1147,10 +1176,12 @@ def _main():
 
             # allow to override, and add more arguments from the command line
             'command': args.command,
-            'ethkey': binascii.a2b_hex(args.ethkey[2:]) if args.ethkey else None,
-            'cskey': binascii.a2b_hex(args.cskey[2:]) if args.cskey else None,
             'username': args.username,
             'email': args.email,
+
+            'ethkey': profile.ethkey,
+            'cskey': profile.cskey,
+
             'market': uuid.UUID(args.market) if args.market else None,
             'market_title': args.market_title,
             'market_label': args.market_label,
@@ -1167,11 +1198,11 @@ def _main():
             'delegate': binascii.a2b_hex(args.delegate[2:]) if args.delegate else None,
             'amount': args.amount or 0,
         }
-        runner = ApplicationRunner(url=args.url, realm=args.realm, extra=extra, serializers=[CBORSerializer()])
+        runner = ApplicationRunner(url=profile.network_url, realm=profile.network_realm, extra=extra, serializers=[CBORSerializer()])
 
         try:
             log.info('Connecting to "{url}" {realm} ..',
-                     url=hlval(args.url), realm=('at realm "' + hlval(args.realm) + '"' if args.realm else ''))
+                     url=hlval(profile.network_url), realm=('at realm "' + hlval(profile.network_realm) + '"' if profile.network_realm else ''))
             runner.run(Client, auto_reconnect=False)
         except Exception as e:
             print(e)
